@@ -4,11 +4,12 @@
 # and the XlsxWriter module.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c) 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 import xlsxwriter
 
-workbook = xlsxwriter.Workbook('tab_colors.xlsx')
+workbook = xlsxwriter.Workbook("tab_colors.xlsx")
 
 # Set up some worksheets.
 worksheet1 = workbook.add_worksheet()
@@ -17,9 +18,9 @@ worksheet3 = workbook.add_worksheet()
 worksheet4 = workbook.add_worksheet()
 
 # Set tab colors
-worksheet1.set_tab_color('red')
-worksheet2.set_tab_color('green')
-worksheet3.set_tab_color('#FF9900')  # Orange
+worksheet1.set_tab_color("red")
+worksheet2.set_tab_color("green")
+worksheet3.set_tab_color("#FF9900")  # Orange
 
 # worksheet4 will have the default color.
 
