@@ -6,15 +6,15 @@
 # https://support.microsoft.com/en-us/office/add-a-watermark-in-excel-a372182a-d733-484e-825c-18ddf3edf009
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c) 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 import xlsxwriter
 
-workbook = xlsxwriter.Workbook('watermark.xlsx')
+workbook = xlsxwriter.Workbook("watermark.xlsx")
 worksheet = workbook.add_worksheet()
 
 # Set a worksheet header with the watermark image.
-worksheet.set_header('&C&[Picture]',
-                     {'image_center': 'watermark.png'})
+worksheet.set_header("&C&[Picture]", {"image_center": "watermark.png"})
 
 workbook.close()
