@@ -7,7 +7,8 @@
 # Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
-from ...workbook import Workbook
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
 
 
@@ -42,7 +43,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        format1 = workbook.add_format({"color": "automatic", "font": "Calibri", "size": 11})
+        format1 = workbook.add_format(
+            {"color": "automatic", "font": "Calibri", "size": 11}
+        )
 
         worksheet.write(0, 0, "Foo", format1)
 
