@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +19,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('table06.xlsx')
+        self.set_filename("table06.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with tables."""
@@ -30,20 +31,20 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.set_column('C:H', 10.288)
+        worksheet.set_column("C:H", 10.288)
 
-        worksheet.add_table('C3:F13')
-        worksheet.add_table('F15:H20')
-        worksheet.add_table('C23:D30')
+        worksheet.add_table("C3:F13")
+        worksheet.add_table("F15:H20")
+        worksheet.add_table("C23:D30")
 
-        worksheet.write('A1', 'http://perl.com/')
-        worksheet.write('C1', 'http://perl.com/')
+        worksheet.write("A1", "http://perl.com/")
+        worksheet.write("C1", "http://perl.com/")
 
-        worksheet.set_comments_author('John')
-        worksheet.write_comment('H1', 'Test1')
-        worksheet.write_comment('J1', 'Test2')
+        worksheet.set_comments_author("John")
+        worksheet.write_comment("H1", "Test1")
+        worksheet.write_comment("J1", "Test2")
 
-        worksheet.insert_image('A4', self.image_dir + 'blue.png')
+        worksheet.insert_image("A4", self.image_dir + "blue.png")
 
         workbook.close()
 
