@@ -6,7 +6,8 @@
 #
 # Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
-from ...workbook import Workbook
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
 
 
@@ -17,13 +18,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-        self.set_filename("utf8_05.xlsx")
-
-        self.ignore_files = [
-            "xl/calcChain.xml",
-            "[Content_Types].xml",
-            "xl/_rels/workbook.xml.rels",
-        ]
+        self.set_filename("utf8_09.xlsx")
 
     def test_create_file(self):
         """Test the creation of an XlsxWriter file with utf-8 strings."""
@@ -31,8 +26,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
         workbook = Workbook(self.got_filename)
 
         worksheet = workbook.add_worksheet()
+        num_format = workbook.add_format({"num_format": "[$¥-411]#,##0.00"})
 
-        worksheet.write_formula("A1", '="Café"', None, "Café")
+        worksheet.write("A1", 1, num_format)
 
         workbook.close()
 
