@@ -3,12 +3,14 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
 import unittest
 from io import StringIO
-from ...sharedstrings import SharedStrings
+
+from xlsxwriter.sharedstrings import SharedStrings
 
 
 class TestWriteSi(unittest.TestCase):
@@ -25,9 +27,9 @@ class TestWriteSi(unittest.TestCase):
     def test_write_si(self):
         """Test the _write_si() method"""
 
-        self.sharedstrings._write_si('neptune')
+        self.sharedstrings._write_si("neptune")
 
         exp = """<si><t>neptune</t></si>"""
         got = self.fh.getvalue()
 
-        self.assertEqual(got, exp)
+        self.assertEqual(exp, got)
