@@ -10,8 +10,9 @@
 import unittest
 from io import StringIO
 
-from ...format import Format
-from ...worksheet import Worksheet
+from xlsxwriter.format import Format
+from xlsxwriter.worksheet import Worksheet
+
 from ..helperfunctions import _xml_to_list
 
 
